A terra-native intersection that first drops the features of each input
that cannot possibly intersect the other (via terra::relate()), so the
underlying GEOS overlay only processes candidate geometries. Equivalent in
result to terra::intersect(), but avoids feeding it large, mostly-disjoint
inputs.
intersect_relate(x, y)SpatVectors (or sources readable by terra::vect()).
A SpatVector of the intersection of the intersecting subsets of
x and y; an empty SpatVector when they are disjoint.